@@ -2,14 +2,12 @@
 
 import os
 import sys
-import json
 import argparse
-import requests
 
 from dtrackauditor.auditor import Auditor
 
-DTRACK_SERVER = os.environ.get('DTRACK_SERVER')
-DTRACK_API_KEY = os.environ.get('DTRACK_API_KEY')
+# DTRACK_SERVER = os.environ.get('DTRACK_SERVER')
+# DTRACK_API_KEY = os.environ.get('DTRACK_API_KEY')
 
 DEFAULT_VERSION = '1.0.0'
 DEFAULT_FILENAME = '../bom.xml'
@@ -39,20 +37,30 @@ def parse_cmd_args():
     parser.add_argument('-l', '--showdetails', type=str,
                         help='displays vulnerabilities details in the stdout based on severity selected. Use with Auto mode.'
                              ' eg values: true or false or all. Default is False.')
+    parser.add_argument('-w', '--wait', action="store_true",
+                        help='wait for uploaded bom to be processed on dependencytrack host.')
+    parser.add_argument('-c', '--getversion', nargs='?', const=1, type=int, help='get version of dependencytrack host. Useful to do a quick '
+                                                            'connection test.')
     args = parser.parse_args()
+
     if args.url is None:
+        DTRACK_SERVER = os.environ.get('DTRACK_SERVER')
+        if DTRACK_SERVER[-1] == '/':
+            DTRACK_SERVER = DTRACK_SERVER[:-1]
         args.url = DTRACK_SERVER
     if not isinstance(args.url, str) or len(args.url) == 0:
-        print('DependencyTrack server URL is required. Set env $DTRACK_SERVER or use --url.')
+        print('DependencyTrack server URL is required. Set env $DTRACK_SERVER or use --url.eg: http://dtrack.my.local')
         sys.exit(1)
     if args.apikey is None:
-        args.apikey = DTRACK_API_KEY
+        DTRACK_API_KEY = os.environ.get('DTRACK_API_KEY')
+        args.apikey = DTRACK_API_KEY.strip()
     if not isinstance(args.apikey, str) or len(args.apikey) == 0:
         print('DependencyTrack api key is required. Set Env $DTRACK_API_KEY or use --apikey.')
         sys.exit(1)
     if args.rules is None:
-        args.rules = ''
-    args.rules = list(map(lambda r: r.strip(), args.rules.split(',')))
+        args.rules = []
+    else:
+        args.rules = list(map(lambda r: r.strip(), args.rules.split(',')))
     if args.version is None:
         args.version = DEFAULT_VERSION
     if args.filename is None:
@@ -64,10 +72,16 @@ def parse_cmd_args():
 def main():
     args = parse_cmd_args()
     dt_server = args.url.strip()
+    if dt_server[-1] == '/':
+        dt_server = dt_server[:-1]
     dt_api_key = args.apikey.strip()
     filename = args.filename.strip()
     show_details = args.showdetails.strip().upper()
 
+    if args.getversion:
+        Auditor.get_dependencytrack_version(dt_server, dt_api_key)
+        sys.exit(0)
+
     if show_details not in ['TRUE', 'FALSE', 'ALL']:
         print('Issue with an option --showdetails. Please check the accepted values.')
         sys.exit(1)
@@ -75,26 +89,22 @@ def main():
        len(args.project) == 0 or \
        args.version is None or \
        len(args.version) == 0:
-        print('Project Name and Version are required. Check help --help.')
+        print('Project Name (-p) and Version (-v) are required. Check help --help.')
         sys.exit(1)
 
     project_name = args.project.strip()
     version = args.version.strip()
 
+    print('Provided project name and version: ', project_name, version)
     if args.auto:
-        Auditor.auto_project_create_upload_bom(
-            dt_server,
-            dt_api_key,
-            project_name,
-            version,
-            args.rules,
-            filename,
-            show_details
-        )
-        return
-    project_uuid = Auditor.project_lookup_create(dt_server, dt_api_key, project_name, version)
-    Auditor.read_upload_bom(dt_server, dt_api_key, project_name, version, filename)
-    print(project_uuid)
+        print('Auto mode ON')
+        Auditor.read_upload_bom(dt_server, dt_api_key, project_name, version, filename, True, wait=args.wait)
+        project_uuid = Auditor.get_project_with_version_id(dt_server, dt_api_key, project_name, version)
+        if project_uuid:
+            Auditor.check_policy_violations(dt_server, dt_api_key, project_uuid)
+            Auditor.check_vulnerabilities(dt_server, dt_api_key, project_uuid, args.rules, show_details)
+    else:
+        Auditor.read_upload_bom(dt_server, dt_api_key, project_name, version, filename, False, wait=args.wait)
 
 if __name__ == '__main__':
    main()
